@@ -5,7 +5,7 @@
 */
 
 #include <konqmainwindowfactory.h>
-#include "../src/konqsettingsxt.h"
+#include "konqsettings.h"
 #include <KLocalizedString>
 
 #include <konqmainwindow.h>
@@ -31,6 +31,8 @@
 #include <QObject>
 #include <QStandardPaths>
 
+using namespace Konq;
+
 class KonqHtmlTest : public QObject
 {
     Q_OBJECT
@@ -48,7 +50,8 @@ private Q_SLOTS:
         bool needsUpdate = false;
         KSharedConfig::Ptr profile = KSharedConfig::openConfig(QStringLiteral("mimeapps.list"), KConfig::NoGlobals, QStandardPaths::ApplicationsLocation);
         KConfigGroup addedServices(profile, "Added KDE Service Associations");
-        for (const QString &mimeType: {"text/html", "application/xhtml+xml", "application/xml"}) {
+        QStringList mimetypes = {"text/html", "application/xhtml+xml", "application/xml"};
+        for (const QString &mimeType: mimetypes) {
             QStringList services = addedServices.readXdgListEntry(mimeType);
             const QString wanted = QStringLiteral("webenginepart.desktop");
             if (services.isEmpty() || services.at(0) != wanted) {
@@ -129,8 +132,8 @@ private Q_SLOTS:
         // Simple test for window.open in a onmousedown handler.
 
         // Want a window, not a tab (historical test)
-        KonqSettings::setMmbOpensTab(false);
-        KonqSettings::setAlwaysHavePreloaded(false);
+        Settings::self()->setMmbOpensTab(false);
+        Konq::Settings::setAlwaysHavePreloaded(false);
 
         // We have to use the same protocol for both the orig and dest urls.
         // KAuthorized would forbid a data: URL to redirect to a file: URL for instance.
