@@ -19,10 +19,11 @@
 #include <QAction>
 #include <qplatformdefs.h> //mode_t
 
+#include <KParts/NavigationExtension>
+
 #include "browserarguments.h"
 #include "windowargs.h"
 #include "browserinterface.h"
-#include "kf5compat.h"
 
 template<class Key, class T>
 class QMap;
@@ -34,8 +35,6 @@ class KFileItemList;
 class QPoint;
 struct DelayedRequest;
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-
 class LIBKONQ_EXPORT BrowserExtension : public KParts::NavigationExtension
 {
     Q_OBJECT
@@ -154,8 +153,4 @@ private:
     BrowserInterface *m_browserInterface = nullptr;
 };
 
-#else
-    using BrowserExtension = KParts::BrowserExtension;
-#endif
-
 #endif
