@@ -265,20 +265,24 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
 #endif
 }
 
-void KonqView::switchEmbeddingPart(const QString& newPluginId, const QString& newInternalViewMode)
+void KonqView::switchViewMode(const QString& newPluginId, const QString& newInternalViewMode)
 {
-    if (service().pluginId() == newPluginId) {
+    bool changePlugin = service().pluginId() != newPluginId;
+    bool changeViewMode = !newInternalViewMode.isEmpty() && newInternalViewMode != internalViewMode();
+    if (!changePlugin && !changeViewMode) {
         return;
     }
+    if (changePlugin) {
     //We don't want to delete the temporary file, otherwise the new part won't have a file to display
-    stop(true);
-    lockHistory();
-    const QUrl origUrl = realUrl();
-    const QString locationBarURL = m_sLocationBarURL;
-    bool tempFile = !m_tempFile.isEmpty();
-    changePart(serviceType(), newPluginId);
-    openUrl(origUrl, locationBarURL, {}, tempFile, url());
-    if (!newInternalViewMode.isEmpty() && newInternalViewMode != internalViewMode()){
+        stop(true);
+        lockHistory();
+        const QUrl origUrl = realUrl();
+        const QString locationBarURL = m_sLocationBarURL;
+        bool tempFile = !m_tempFile.isEmpty();
+        changePart(serviceType(), newPluginId);
+        openUrl(origUrl, locationBarURL, {}, tempFile, url());
+    }
+    if (changeViewMode){
         setInternalViewMode(newInternalViewMode);
     }
 }
@@ -1379,29 +1383,6 @@ HistoryEntry* HistoryEntry::fromDelayedLoadingData(const KConfigGroup& config, c
     return entry;
 }
 
-void HistoryEntry::loadItem(const KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options)
-{
-    if (options & (KonqFrameBase::SaveUrls|KonqFrameBase::SaveHistoryItems)) { // either one
-        url = QUrl(config.readEntry(QStringLiteral("Url").prepend(prefix), ""));
-        locationBarURL = config.readEntry(QStringLiteral("LocationBarURL").prepend(prefix), "");
-        title = config.readEntry(QStringLiteral("Title").prepend(prefix), "");
-        strServiceType = config.readEntry(QStringLiteral("StrServiceType").prepend(prefix), "");
-        strServiceName = config.readEntry(QStringLiteral("StrServiceName").prepend(prefix), "");
-    }
-    if (options & KonqFrameBase::SaveUrls) {
-        reload = true;
-    } else if (options & KonqFrameBase::SaveHistoryItems) {
-        buffer = config.readEntry(QStringLiteral("Buffer").prepend(prefix), QByteArray());
-        postData = config.readEntry(QStringLiteral("PostData").prepend(prefix), QByteArray());
-        postContentType = config.readEntry(QStringLiteral("PostContentType").prepend(prefix), "");
-        doPost = config.readEntry(QStringLiteral("DoPost").prepend(prefix), false);
-        pageReferrer = config.readEntry(QStringLiteral("PageReferrer").prepend(prefix), "");
-        pageSecurity = static_cast<KonqMainWindow::PageSecurity>(config.readEntry(
-                           QStringLiteral("PageSecurity").prepend(prefix), 0));
-        reload = false;
-    }
-}
-
 Konq::PlaceholderPart* KonqView::placeholderPart() const
 {
     return qobject_cast<Konq::PlaceholderPart*>(m_pPart);
