@@ -7,7 +7,7 @@
 */
 
 #include "urlloader.h"
-#include "konqsettings.h"
+#include "konqembedsettings.h"
 #include "konqmainwindow.h"
 #include "konqview.h"
 #include "konqurl.h"
@@ -79,9 +79,7 @@ UrlLoader::UrlLoader(KonqMainWindow *mainWindow, KonqView *view, const QUrl &url
     m_protocolAllowsReading(KProtocolManager::supportsReading(m_url) || !KProtocolInfo::isKnownProtocol(m_url)), // If the protocol is unknown, assume it allows reading
     m_letRequestingPartDownloadUrl(req.letPartPerformDownload)
 {
-    //TODO KF6: currently there's no way to pass the suggested file name. When dropping compatibility with KF5, have a field for this
-    //in BrowserArguments
-    m_request.suggestedFileName = m_request.args.metaData().value(QStringLiteral("SuggestedFileName"));
+    m_request.suggestedFileName = m_request.browserArgs.suggestedDownloadName();
 
     //TODO KF6: when dropping compatibility with KF5, stop using metadata and add appropriate fields to BrowserArguments
     QString requestedEmbeddingPart = m_request.args.metaData().value(QStringLiteral("embed-with"));
@@ -297,29 +295,43 @@ KPluginMetaData UrlLoader::findEmbeddingPart(bool forceServiceName) const
 {
     const QLatin1String webEngineName("webenginepart");
 
-    //Use WebEnginePart for konq: URLs even if it's not the default html engine
+    // Use WebEnginePart for konq: URLs even if it's not the default HTML engine
     if (KonqUrl::hasKonqScheme(m_url)) {
         return findPartById(webEngineName);
     }
 
     KPluginMetaData part;
 
-    //Check whether the view can display the mimetype, but only if the URL hasn't been explicitly
-    //typed by the user: in this case, use the preferred service. This is needed to avoid the situation
-    //where m_view is a Kate part, the user enters the URL of a web page and the page is opened within
-    //the Kate part because it can handle html files.
-    if (m_view && m_request.typedUrl.isEmpty() && m_view->supportsMimeType(m_mimeType)) {
-        part = m_view->service();
-    } else if (!m_request.serviceName.isEmpty()) {
-        // If the service name has been set by the "--part" command line argument
-        // (detected in handleCommandLine() in konqmain.cpp), then use it as is.
+    // If the service name has been set by the "--part" command line
+    // argument via KonquerorApplication::createWindowsForUrlArguments(),
+    // then use it as is.  It will only be set for the first call with
+    // that command invocation.
+    //
+    // This test must be performed before the 'existing view' test below,
+    // because at this point the view showing the "konq:blank" page already
+    // exists.
+    if (!m_request.serviceName.isEmpty()) {
         part = findPartById(m_request.serviceName);
-        if (!forceServiceName && !part.supportsMimeType(m_mimeType)) {
-            part = KPluginMetaData();
-        }
+    }
+
+    // Check whether the current view can display the MIME type, but only if
+    // the URL hasn't been explicitly typed by the user: in this case, use the
+    // preferred service. This is needed to avoid the situation where m_view
+    // is a Kate part, the user enters the URL of a web page, and the page is
+    // opened within the Kate part because it can handle HTML files.
+    if (!part.isValid() && m_view && m_request.typedUrl.isEmpty() && m_view->supportsMimeType(m_mimeType)) {
+        part = m_view->service();
+    }
+
+    // If the part does not support the required MIME type, then it cannot be
+    // used. The only exception is when we are forced to use the given service.
+    if (part.isValid() && !forceServiceName && !part.supportsMimeType(m_mimeType)) {
+        part = KPluginMetaData();
     }
 
     if (!part.isValid()) {
+        // Now, if no part has yet been resolved, then use the preferred part
+        // for the MIME type.
         part = preferredPart(m_mimeType);
     }
 
@@ -406,6 +418,7 @@ void UrlLoader::decideOpenOrSave()
     //or emptied.
     if (m_letRequestingPartDownloadUrl && m_action == OpenUrlAction::Open && m_partDownloaderJob) {
         QString fileName = QFileInfo(m_partDownloaderJob->downloadPath()).fileName();
+        fileName = Konq::generateUniqueFileName(fileName, QDir::temp().path());
         m_partDownloaderJob->setDownloadPath(QDir::temp().filePath(fileName));
     }
     if (!m_service) {
